==> ejc-ai-impl-3.0.0-20250327.122043-64-sources.jar: com/ejianc/foundation/ai/vo/KnowledgeEmbeddingPointsVO.java <==
package com.ejianc.foundation.ai.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识库切片知识点表
 * 
 * @author generator
 * 
 */
public class KnowledgeEmbeddingPointsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long embeddingId; // 切片ID
    private String uuid; // 系统生成id
    private String vector; // 向量
    private String content; // 知识内容
    private String initContent; // 自动生成的初始化的知识内容
    private Integer type; //类型，1自动生成，2自定义新增
    private Integer sequence; // 排序号

    public Long getEmbeddingId() {
        return embeddingId;
    }

    public void setEmbeddingId(Long embeddingId) {
        this.embeddingId = embeddingId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getVector() {
        return vector;
    }

    public void setVector(String vector) {
        this.vector = vector;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
}

==> ejc-ai-impl-3.0.0-20250423.074155-110-sources.jar: com/ejianc/foundation/ai/vo/KnowledgeEmbeddingPointsVO.java <==
package com.ejianc.foundation.ai.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识库切片知识点表
 * 
 * @author generator
 * 
 */
public class KnowledgeEmbeddingPointsVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long embeddingId; // 切片ID
    private String uuid; // 系统生成id
    private String vector; // 向量
    private String content; // 知识内容
    private String initContent; // 自动生成的初始化的知识内容
    private Integer type; //类型，1自动生成，2自定义新增，2包含标签（不支持前端显示的向量数据）
    private Integer sequence; // 排序号

    public Long getEmbeddingId() {
        return embeddingId;
    }

    public void setEmbeddingId(Long embeddingId) {
        this.embeddingId = embeddingId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getVector() {
        return vector;
    }

    public void setVector(String vector) {
        this.vector = vector;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
}
